@@ -3,6 +3,7 @@ import os
 import re
 import sh
 import shutil
+import textwrap
 import yaml
 
 from enough.common.dotenough import DotEnough, Hosts
@@ -98,20 +99,28 @@ class Enough(object):
     def clone(self, target_domain, target_cloud, clobber_cloud):
         config_base = os.path.dirname(self.config_dir)
         config_dir = f'{config_base}/{target_domain}'
-        if not os.path.exists(config_dir) or clobber_cloud:
+        if clobber_cloud and os.path.exists(config_dir):
+            shutil.rmtree(config_dir)
+        if not os.path.exists(config_dir):
             sh.rsync('-a', '--delete',
                      '--exclude=private-key.yml',
                      '--exclude=hosts.yml',
                      '--exclude=group_vars/all/domain.yml',
                      '--exclude=group_vars/all/production_domain.yml',
+                     '--exclude=group_vars/all/internal_network.yml',
                      f'{self.config_dir}/', f'{config_dir}/')
+            all_dir = f'{config_dir}/inventory/group_vars/all'
+            open(f'{all_dir}/internal_network.yml', 'w').write(textwrap.dedent(f"""\
+            ---
+            openstack_internal_network_prefix: "10.11.10.0"
+            openstack_internal_network_cidr: "10.11.10.0/24"
+            """))
             clone_override_dir = f'{config_base}/clone-override'
             if os.path.exists(clone_override_dir):
                 log.info(f'overriding with {clone_override_dir}')
                 sh.rsync('-av', '--checksum', f'{clone_override_dir}/', f'{config_dir}/')
             if os.path.exists(f'{self.config_dir}.pass'):
                 shutil.copyfile(f'{self.config_dir}.pass', f'{config_dir}.pass')
-            all_dir = f'{config_dir}/inventory/group_vars/all'
             self.replace_production(f'{all_dir}/clouds.yml', target_cloud)
         kwargs = {
             'driver': self.args['driver'],
