@@ -23,12 +23,12 @@ class OpenStackBase(object):
     INTERNAL_NETWORK = 'internal'
     INTERNAL_NETWORK_CIDR = '10.20.30.0/24'
 
-    def __init__(self, config_dir, config_file, **kwargs):
+    def __init__(self, config_dir, **kwargs):
         self.args = kwargs
         self.config_dir = config_dir
-        self.config_file = config_file
+        self.config_file = f'{self.config_dir}/inventory/group_vars/all/clouds.yml'
         self.o = sh.openstack.bake(
-            '--os-cloud=ovh',
+            '--os-cloud', kwargs.get('cloud', 'production'),
             _tee=True,
             _out=lambda x: log.info(x.strip()),
             _err=lambda x: log.info(x.strip()),
@@ -38,8 +38,8 @@ class OpenStackBase(object):
 
 class Stack(OpenStackBase):
 
-    def __init__(self, config_dir, config_file, definition=None, **kwargs):
-        super().__init__(config_dir, config_file, **kwargs)
+    def __init__(self, config_dir, definition=None, **kwargs):
+        super().__init__(config_dir, **kwargs)
         log.info(f'OS_CLIENT_CONFIG_FILE={self.config_file}')
         self.definition = definition
 
@@ -107,13 +107,13 @@ class Stack(OpenStackBase):
     def create_internal_network(self):
         network = self.definition.get('internal_network', OpenStackBase.INTERNAL_NETWORK)
         cidr = self.definition.get('internal_network_cidr', OpenStackBase.INTERNAL_NETWORK_CIDR)
-        o = OpenStack(self.config_dir, self.config_file)
+        o = OpenStack(self.config_dir, **self.args)
         o.network_and_subnet_create(network, cidr)
 
     def connect_internal_network(self):
         server = self.definition['name']
         network = self.definition.get('internal_network', OpenStackBase.INTERNAL_NETWORK)
-        o = OpenStack(self.config_dir, self.config_file)
+        o = OpenStack(self.config_dir, **self.args)
         if o.server_connected_to_network(server, network):
             return
         self.o.server.add.network(server, network)
@@ -161,7 +161,7 @@ class Stack(OpenStackBase):
         Hosts(self.config_dir).delete(name)
 
         network = self.definition.get('internal_network', OpenStackBase.INTERNAL_NETWORK)
-        o = OpenStack(self.config_dir, self.config_file)
+        o = OpenStack(self.config_dir, **self.args)
         o.network_delete_if_not_used(network)
 
     def delete(self):
@@ -225,7 +225,7 @@ class Heat(OpenStackBase):
         # Launch the creation of all stacks in // and do not wait for them to complete
         #
         for name in names:
-            s = Stack(self.config_dir, self.config_file, self.get_stack_definition(name),
+            s = Stack(self.config_dir, self.get_stack_definition(name),
                       **self.args)
             s.set_public_key(public_key)
             info = s.create_or_update(return_on_create=True)
@@ -237,7 +237,7 @@ class Heat(OpenStackBase):
         # Verify all stacks previously launched complete as expected
         #
         for name in created:
-            s = Stack(self.config_dir, self.config_file, self.get_stack_definition(name),
+            s = Stack(self.config_dir, self.get_stack_definition(name),
                       **self.args)
             s.set_public_key(public_key)
             info = s.create_or_update(return_on_create=True)
@@ -247,10 +247,10 @@ class Heat(OpenStackBase):
     def create_test_subdomain(self, domain):
         d = f"{self.config_dir}/inventory/group_vars/all"
         assert os.path.exists(d)
-        if 'bind-host' not in Stack(self.config_dir, self.config_file, **self.args).list():
+        if 'bind-host' not in Stack(self.config_dir, **self.args).list():
             return None
-        h = Heat(self.config_dir, self.config_file)
-        s = Stack(self.config_dir, self.config_file, h.get_stack_definition('bind-host'),
+        h = Heat(self.config_dir, **self.args)
+        s = Stack(self.config_dir, h.get_stack_definition('bind-host'),
                   **self.args)
         s.set_public_key(f'{self.config_dir}/infrastructure_key.pub')
         bind_host = s.create_or_update()
@@ -286,11 +286,15 @@ class OpenStackBackupCreate(Exception):
     pass
 
 
+class OpenStackShutoff(Exception):
+    pass
+
+
 class OpenStack(OpenStackBase):
 
-    def __init__(self, config_dir, config_file):
-        super().__init__(config_dir, config_file)
-        self.config = yaml.load(open(config_file))
+    def __init__(self, config_dir, **kwargs):
+        super().__init__(config_dir, **kwargs)
+        self.config = yaml.load(open(self.config_file))
 
     @retry(OpenStackLeftovers, tries=7)
     def destroy_everything(self, prefix):
@@ -458,18 +462,32 @@ class OpenStack(OpenStackBase):
             count += 1
         return count
 
-    def replace_volume(self, host, volume):
+    @retry(OpenStackShutoff, tries=5)
+    def server_wait_shutoff(self, host):
+        status = self.o.server.show('--format=value', '-c=status', host)
+        status = status.strip()
+        if status != 'SHUTOFF':
+            raise OpenStackShutoff()
+
+    def replace_volume(self, host, volume, delete_volume):
         self.o.server.stop(host)
+        self.server_wait_shutoff(host)
         attached = self.o.server.show(
             '--format=value', '-c', 'volumes_attached', host).stdout.strip()
         current_volume_id = re.sub("id='(.*)'", "\\1", attached.decode('utf-8'))
         current_volume = self.o.volume.show(
             '--format=value', '-c', 'name', current_volume_id).strip()
-        self.o.server.remove.volume(host, current_volume)
-        self.o.volume.delete(current_volume)
-        self.o.server.add.volume(host, volume)
+        volume_id = self.o.volume.show('--format=value', '-c', 'id', volume).stdout.strip()
+        self.o.server.remove.volume(host, current_volume_id)
+        if delete_volume:
+            # using current_volume_id here is not possible unfortunately
+            self.o.volume.delete(current_volume)
+        else:
+            date = self.backup_date()
+            self.o.volume.set('--name', f'{date}-{current_volume}', current_volume_id)
+        self.o.volume.set('--name', current_volume, volume_id)
+        self.o.server.add.volume(host, volume_id)
         self.o.server.start(host)
-        self.o.volume.set('--name', current_volume, volume)
 
     def region_empty(self):
         volumes = self.o.volume.list()
