@@ -18,10 +18,9 @@ def test_icingaweb2_login_screen(host, pytestconfig):
     address = get_address(pytestconfig.getoption("--ansible-inventory"))
     proto_srv = f"https://{address}"
     s = requests.Session()
-    s.verify = 'certs'
-    r = s.get(proto_srv+'/icingaweb2/authentication/login', timeout=5)
+    r = s.get(proto_srv+'/icingaweb2/authentication/login', timeout=20, verify='certs')
     cookies = dict(r.cookies)
     r = s.get(proto_srv+'/icingaweb2/authentication/login?_checkCookie=1',
-              cookies=cookies, timeout=5)
+              cookies=cookies, timeout=5, verify='certs')
     r.raise_for_status()
     assert 'Icinga Web 2 Login' in r.text
