@@ -33,7 +33,7 @@ def test_openstack_create_or_update(tmpdir, openstack_name, requests_mock):
 
 def test_service_from_host():
     s = service.Service(settings.CONFIG_DIR, settings.SHARE_DIR, domain='test.com')
-    assert s.service_from_host('icinga-host') in ('essential', 'openvpn', 'wekan')
+    assert s.service_from_host('icinga-host') is None
     assert s.service_from_host('cloud-host') == 'cloud'
     assert s.service_from_host('unknown-host') is None
 
@@ -50,12 +50,14 @@ def test_update_vpn_dependencies():
     assert s.hosts_with_internal_network(['bind-host']) == []
     assert 'website-host' not in s.service2hosts['openvpn']
     assert 'website-host' not in s.service2hosts['weblate']
+    assert 'weblate-host' in s.service2hosts['weblate']
     s.ansible.set_inventories(['tests/enough/common/test_common_service/vpn_inventory'])
     s.set_service_info()
     assert 'website-host' in s.service2hosts['openvpn']
     assert s.hosts_with_internal_network(['icinga-host']) == ['icinga-host']
     s.update_vpn_dependencies()
-    assert 'website-host' in s.service2hosts['weblate']
+    assert 'website-host' not in s.service2hosts['weblate']
+    assert 'weblate-host' in s.service2hosts['weblate']
 
 
 def test_ensure_non_empty_service_group(tmpdir):
