@@ -30,8 +30,8 @@ clouds:
   production:
     auth: &os_auth
       auth_url: "$OS_AUTH_URL"
-      project_name: "$OS_PROJECT_NAME"
-      project_id: "$OS_PROJECT_ID"
+      project_name: "${OS_PROJECT_NAME:-OS_TENANT_NAME}"
+      project_id: "${OS_PROJECT_ID:-$OS_TENANT_ID}"
       user_domain_name: "$OS_USER_DOMAIN_NAME"
       username: "$OS_USERNAME"
       password: "$OS_PASSWORD"
